pub struct CudaRuntime;Trait Implementations
Sourceimpl Clone for CudaRuntime
impl Clone for CudaRuntime
Sourcefn clone(&self) -> CudaRuntime
fn clone(&self) -> CudaRuntime
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CudaRuntime
impl Debug for CudaRuntime
Sourceimpl Runtime for CudaRuntime
impl Runtime for CudaRuntime
Sourcetype Compiler = CppCompiler<CudaDialect<CudaWmmaCompiler>>
type Compiler = CppCompiler<CudaDialect<CudaWmmaCompiler>>
The compiler used to compile the inner representation into tokens.
Sourcetype Device = CudaDevice
type Device = CudaDevice
The device used to retrieve the compute client.
Sourcefn client(device: &Self::Device) -> ComputeClient<Self>
fn client(device: &Self::Device) -> ComputeClient<Self>
Retrieve the compute client from the runtime device.
Sourcefn name(_client: &ComputeClient<Self>) -> &'static str
fn name(_client: &ComputeClient<Self>) -> &'static str
The runtime name on the given device.
Sourcefn require_array_lengths() -> bool
fn require_array_lengths() -> bool
Return true if global input array lengths should be added to kernel info.
Sourcefn max_cube_count() -> (u32, u32, u32)
fn max_cube_count() -> (u32, u32, u32)
Returns the maximum cube count on each dimension that can be launched.
Sourcefn can_read_tensor(shape: &Shape, strides: &Strides) -> bool
fn can_read_tensor(shape: &Shape, strides: &Strides) -> bool
Whether a tensor with
shape and strides can be read as is. If the result is false, the
tensor should be made contiguous before reading.Sourcefn target_properties() -> TargetProperties
fn target_properties() -> TargetProperties
Returns the properties of the target hardware architecture.
Sourcefn enumerate_devices(
_: u16,
_: &<Self::Server as ComputeServer>::Info,
) -> Vec<DeviceId>
fn enumerate_devices( _: u16, _: &<Self::Server as ComputeServer>::Info, ) -> Vec<DeviceId>
Returns all devices available under the provided type id.
Sourcefn enumerate_all_devices(
info: &<Self::Server as ComputeServer>::Info,
) -> Vec<DeviceId>
fn enumerate_all_devices( info: &<Self::Server as ComputeServer>::Info, ) -> Vec<DeviceId>
Returns all devices that can be handled by the runtime.